@@ -1,4 +1,5 @@
 from .alias_controller import Alias
+from .filter_controller import Filter
 
 class Firewall(object):
 
@@ -8,3 +9,7 @@ class Firewall(object):
   @property
   def alias_controller(self) -> Alias:
     return Alias(self._device)
+
+  @property
+  def filter_controller(self) -> Filter:
+    return Filter(self._device)
